#
# spec file for package diskimage-builder
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 1.16.2.dev29

Name:           diskimage-builder
Version:        1.16.2~a0~dev29
Release:        1.3
Summary:        Image Building Tools for OpenStack
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/diskimage-builder
Source:         http://tarballs.openstack.org/diskimage-builder/diskimage-builder-master.tar.gz
Requires:       python-Babel >= 2.3.4
Requires:       python-dib-utils
BuildRequires:  python-PyYAML
BuildRequires:  python-devel
BuildRequires:  python-pbr >= 0.5.10
BuildRequires:  python-setuptools
Requires:       python-PyYAML >= 3.1.0
Requires:       python-six >= 1.9.0
Requires:       qemu-tools
# Prevent shebangs of element scripts from being added as a requirement (they
# are only ever run inside the disk image build chroot).
%global         __requires_exclude_from ^%{_datadir}/%{name}/elements/.*$
# Test requirements:
BuildRequires:  python-fixtures
BuildRequires:  python-oslotest
BuildRequires:  python-testrepository
BuildRequires:  python-testtools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-argparse
BuildRequires:  python-discover
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
# No stuff in python_sitelib, thus autoreqprov won't work:
Requires:       python(abi) = %{py_ver}
BuildArch:      noarch
%endif

%description
These tools are the components of TripleO
(https://wiki.openstack.org/wiki/TripleO) that are responsible for
building disk images.

%prep
%setup -q -n %{name}-%{version_unconverted}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
if [ ! -d ./.testrepository ] ; then testr init ; fi
testr run %{?_smp_mflags:--parallel %_smp_flags} #; RET=$? echo "Slowest Tests" ; testr slowest && exit $RET

%files
%defattr(-,root,root,-)
%doc ChangeLog README.rst LICENSE AUTHORS
%{_bindir}/dib-lint
%{_bindir}/element-info
%{_bindir}/*disk-image-create
%{_datadir}/%{name}
%{python_sitelib}/diskimage_builder/
%{python_sitelib}/diskimage_builder-%{version_unconverted}*.egg-info/

%changelog
* Wed Jun  8 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev29:
  * Release notes for 1.17.0
* Tue Jun  7 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev27:
  * Cleanup source-repositories output
  * Refactor: rename temporary directories
  * Refactor: remove unused functions
  * Export die() function
  * Fix variable unbound error while REPOREF="*"
  * Handle file magic type varying order matching
  * Add cloud-initramfs-growroot for Precise
  * Add release to pkg-map
  * Export FS_TYPE and remove hardcoded ext4 values
  * Add PS4 to show file/function/line in debug output
* Wed Jun  1 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev7:
  * Rework yum-minimal locale cleanup
* Tue May 31 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev5:
  * Remove Fedora 21 from test-build
* Fri May 27 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev4:
  * Add a best-effort sudo safety check
* Thu May 26 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev3:
  * Remove deprecated overriding of cloud-init defaults
* Mon May 23 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev2:
  * Fix apt-sources configuration for debian-minimal
* Thu May 19 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.2.dev1:
  * Add dhcp-all-interfaces.target for syncing units
* Wed May 18 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.1:
  1.16.1
  * Revert "Revert "Properly fail/trap in eval_run_d"" and fix PIPESTATUS
  * Fix path issue for locale-archive.tmpl
  * Revert "Properly fail/trap in eval_run_d"
  * Add centos7 test
* Tue May 17 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.16.1.dev1:
  * Small doc update, add link to relnotes
  1.16.0
  * centos-minimal: can be used with base
  * Add 1.16.0 releasenotes
* Mon May 16 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.15.1.dev25:
  * Properly fail/trap in eval_run_d
  * Do not remove sudo in ironic-agent
* Sat May 14 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.15.1.dev21:
  * Add EPEL as requirement of centos-minimal
* Fri May 13 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.15.1.dev20:
  * Add install-bin element
  * tests/elements/fake-os: add '/tmp' as top level dir
  * Updated from global requirements
  * Install proliantutils in IPA's virtualenv
  * Add test dependency installation on Gentoo
  * Split YAML & JSON parsing
  * Add some output to dib-lint
  * yum-minimal: strip locale archive
  * yum-minimal : better cleanup of initial yum failure
  * Fix up EPEL element
* Thu May 12 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.15.1.dev5:
  * Fix OpenSUSE support
* Mon May  9 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.15.1.dev3:
  * Add documentation for dib-lint
  1.15.0
  * Remove cloud-initramfs-growroot package
* Mon May  9 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev37:
  * Use generic "dhcp-client" name
* Fri Apr 22 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev36:
  * dhcp-all-interfaces depends on dib-init-system
  * dhcp-all-interfaces depends on dhcp
  * Add Gentoo to the dhcp-all-interfaces element
  * Updated from global requirements
  * Add releasenotes
  * Move selinux restore to end of finalise
  * Handle unconfigured interfaces for dhcp-all-ifaces
  * Really remove all interfaces in dhcp-all-ifaces
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev25:
  * Change to latest CentOS-6 image
  * Document upstream executable numbering convention
  * Allow skipping the md docs check
  * Don't stop dib-lint on first flake8 failure
  * Updated from global requirements
  * simple-init: Fix path for /etc/ssh test
  * Fix disk usage report
  * Add qcow2 generation for better test coverage
  * Skip gentoo test
  * Fix add-apt-repository package for precise
  * dib-run-parts: make cp to target root more robust
  * Prioritize venv python on host
* Fri Apr 15 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev5:
  * Support to add certificate in ironic-agent
  * Fallback to a boot_server kernel param if ip=  not passed
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev3:
  * Debian: dont set always the hostname to debian
  * Turn down tracing for source-repo cache
* Thu Apr  7 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.14.2.dev1:
  * Turn of tracing around du invocations
  1.14.1
  * Fix ssh key cleanup to run in chroot
  1.14.0
  * Remove ssh host keys when using simple init
  * Revert "Skip centos functional testing"
* Tue Apr  5 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.13.1.dev6:
  * ironic-agent postinst fails on systemd with no iptables
* Sun Apr  3 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.13.1.dev5:
  * Set tgtd not auto-start on OS boot time
  * Add image size report
* Fri Apr  1 2016 johannes.grassler@suse.com
- Replaced __requires_exclude for /usr/local/bin/dib-python by a
  blanket exclusion for /usr/share/diskimage-builder/elements/.
* Fri Apr  1 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.13.1.dev2:
  * ironic-python-agent should use console output
* Wed Mar 30 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.13.1.dev1:
  1.13.0
  * add pkg-map to pip-and-virtualenv element
  * Remove all interface configs for simple-init
  * Set default locale to image in debootstrap element
* Tue Mar 22 2016 johannes.grassler@suse.com
- Added missing dependencies on python-flake8 and python-six
- Added __requires_exclude for /usr/local/bin/dib-python
  Tue Mar 22 16:38:28 UTC 2016 -
- Update to version diskimage-builder-1.12.1.dev11:
  * Add psmisc to the packages for ironic-agent
  * Note requirement for parted on gentoo hosts
* Tue Jan  5 2016 cloud-devel@suse.de
- Update to version diskimage-builder-1.6.1.dev1:
  * The mirror for installing epel is timing out
  1.6.0
* Thu Dec 24 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev30:
  * Document byte-to-inode ratio
* Wed Dec 23 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev28:
  * yum-minimal : install selinux policy packages
  * yum-minimal: do not configure eth0 & eth1 for DHCP automatically
  * yum-minimal: leave behind dummy /etc/resolv.conf
  * Fix growroot device detection
  * Package installs defaults to tracing off
  * Don't print trace unless trace is on in pkg-map
  * Extend root device hints for different types of WWN
* Tue Dec 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev15:
  * Fix unmount/remove race in cleanup_build_dir
* Sat Dec 19 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev14:
  * Split vm and bootloader elements
  * Support building ACIs
* Thu Dec 17 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev11:
  * Deprecated tox -downloadcache option removed
* Wed Dec 16 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev9:
  * Add dib-python element
  * Allow grub2 to build with opensuse
  * Fix fedora-minimal on CentOS builds
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.5.1.dev4:
  * Add a new element hpdsa
  1.5.0
  * Follow up patch for 25d3ee547176528e86d42eb026c99a134dff9452
  * Add proliant-tools element
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.4.1.dev15:
  * Add kmod to package-installs of ironic-agent
  * Load the 8021q kernel module in simple-init
  * Fix grub-efi-amd64-signed install failure
  * Use ironic-agent for source-repositories
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.4.1.dev7:
  * Add openssh-server package-install to local-config
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.4.1.dev6:
  * Updated from global requirements
  * Add dynamic-login element
* Mon Nov 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.4.1.dev3:
  * Add DIB_LOCAL_CONFIG_USERNAME to local-config
* Thu Nov 26 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.4.1.dev1:
  1.4.0
  * Move install-types doc to user guide
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.3.1.dev1:
  * Remove fedora-minimal/install.d/99-ramdisk
  1.3.0
* Sat Nov 14 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev35:
  * Selectively prune /root for ironic-agent ramdisk
* Wed Nov 11 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev33:
  * Fixup RPM db path when building Fedora on Ubuntu
  * Remove unused RELEASE_RPMS variable
  * Fix fedora-minimal kernel-install on older platforms
  * Clarify what fedora-minimal/install.d/99-ramdisk is doing
* Tue Nov 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev26:
  * Fix diskimage-builder image size
  * Add --force to grub-install
  * dib-lint: ignore blank lines in element ordering
* Fri Nov  6 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev22:
  * Add missing six requirement for svc-map element
  * Fix uniqueness check of initrd in fedora-minimal
* Thu Nov  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev18:
  * debian: cloud hostname ignored by Jessie
  * Add support for Xen PV disks
* Wed Nov  4 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev15:
  * Updated from global requirements
  * Add a tox target to run functional tests locally
  * Preserve env when calling yum with sudo
  * Define a default for $YUM
* Tue Nov  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev10:
  * Enable decimal value for $DIB_IMAGE_SIZE
  * Remove quotes from subshell call in bash script
  * Prettyfy source-repositories doc
  * Prettify 'Caches and offline mode' documentation
  * Prettify 'Developing Elements' documentation
* Sun Oct 25 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev5:
  * Create YUM_CACHE_DIR in yum-minimal
* Thu Oct 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev4:
  * Use DIB_EPEL_MIRROR when finding the epel-release package
* Wed Oct 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev2:
  * Fix tests/test_functions.bash
* Tue Oct 20 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.2.1.dev1:
  1.2.0
  * Fix devuser pubkey defaults
  * Add flake8 to requirements
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev55:
  * Reset yum/dnf cache to correct location
  * Remove extra install of release pkgs in fedora-minimal
  * Update default fedora-minimal to f22
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev49:
  * Add Fedora 22 support to yum-minimal
  * Update rhel7 element readme
* Mon Oct 12 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev46:
  * Update apt-preferences element README from free text to table formatting
  * Update apt-conf elements README from free text to table formatting
  * Adds debian support to iso element
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev40:
  * Move yum-based install into function
  * Fix title of env vars section of fedora README to match template
  * Fix title of env vars section of redhat-common README to match template
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev35:
  * Avoid transcending /proc with find
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev33:
  * Reorder the script number of 'elements/dkms/post-install.d/99-dkms'
* Tue Oct  6 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev32:
  * agent: ensure vmlinuz file does not exist before hard-linking into it
  * Prevent overwriting of user modified blacklist.conf
* Sat Oct  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev28:
  * Restrict search for python object files to ./usr
* Fri Oct  2 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev27:
  * Use --nodeps when installing fedora-release
* Thu Oct  1 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev25:
  * Install 'gdisk' when building ramdisk with ironic-agent
  * Output failing lines when dib-lint finds wrong indents
  * Fix variable misspelling error
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev19:
  * Contains the directory name of /sys and /proc
  * Add functional test for ironic-agent on Fedora
* Fri Sep 25 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev15:
  * Updated from global requirements
  * svc-map: do not specify user/group for install
  * Activate pep8 check that _ is imported
* Fri Sep 25 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev11:
  * ironic-agent element to output a .kernel file
  * Remove dnf workaround in ironic-agent
  * ironic-agent: remove python object files
  * Install ironic-agent dependencies via package-installs
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev3:
  * Add option to set EPEL mirror
* Sat Sep 19 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.3.dev2:
  1.1.2
  * Download a compressed centos cloud images
  * Add centos7 support for DIB_DISTRIBUTION_MIRROR
  * Deprecate the deploy-ironic element
* Fri Sep 18 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev27:
  * Don't create a centos yum repository
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev25:
  * Add #!/bin/bash to library functions
  * Make README.rst a bit more generic
  * doc: migrate from README.rst to Sphinx
  * Update fedora elements README from free text to table formatting
  * Update redhat-common elements README from free text to table formatting
  * Fix test cleanup trap to cleanup tmpdir
* Wed Sep 16 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev15:
  * dib-lint: validate json/yaml files
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev14:
  * Add documentation of output formats for users
* Fri Sep 11 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev13:
  * Make sure dnf won't autoremove packages that we explicitly installed
* Fri Sep  4 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev12:
  * Remove grub2 in redhat-common/pre-install.d/15-remove-grub
  * Remove old entries from MANIFEST.in
  * ironic-agent: ensure dmidecode and ipmitool are installed
  * [ironic-agent] Use svc-map for enabling agent
  * Update dpkg elements README from free text to table formatting
* Sat Aug 29 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev4:
  * Fix ironic-image pkg-map
  * Fix a typo in README.rst
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.1.2.dev1:
  1.1.1
  * Run growroot after all filesystems are mounted
  * Updated from global requirements
  1.1.0
  * create growroot element
  * Reduce the size of the ironic-agent ramdisk
* Sat Aug 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev29:
  * Add ability to build ironic-python-agent ramdisk from packages
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev27:
  * Install-static depends on rsync
  * Fix init-scripts element path munging and deps
  * Add test for centos 6
  * Add explicit f21 test
* Sat Aug 15 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev21:
  * Pin the Fedora mirror for testing
  * Remove docker doc from docs
* Sat Aug  8 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev17:
  * Set and export DIB_RELEASE for centos7
  * Handle modern sfdisk and correctly align image partition
* Fri Aug  7 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev13:
  * Add element to disable cloud-init resizefs
* Thu Aug  6 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev12:
  * Correct URL in ironic-agent README
  * Add curl to ironic-agent package installs
  * debian: properly configure interfaces
* Wed Aug  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev8:
  * Set DIB_RELEASE for the Debian test-element
  * Adds Ubuntu and Debian to ironic-python-agent Support-list
  * Fix link in installation doc
  * typos on the document
  * Only warn about missing map files with debug
* Thu Jul 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-1.0.1.dev1:
  1.0.0
  * Add init-scripts directory support
* Mon Jul 27 2015 tbechtold@suse.com
- Update to version diskimage-builder-0.1.48.dev31:
  * Document what our stable interfaces are
  * Update default Fedora to 22
  * Document our supported distributions
  * opensuse: Update README
  * openSUSE: Fix link to the images download folder
* Fri Jul 24 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev21:
  * Use official mirror name for debian-minimal
* Wed Jul 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev19:
  * debian: install DHCP client and ifconfig packages
* Tue Jul 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev17:
  * Cleanup yum downloading
  * Add base element for using docker as image base
* Mon Jul 20 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev14:
  * Add docker output support
  * Use the init scripts from the glean package
* Sat Jul 18 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev10:
  * Work around yum/dnf differences
  * Add YUM variable to for Fedora >= 22
  * ramdisk: enable ppc64 support for symlink
* Wed Jul 15 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev7:
  * Cleanup the build directories earlier
* Fri Jul 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev6:
  * Removes hardcoded refrences for ethernet interface
  * Remove deprecated disk-image-get-kernel
* Fri Jul  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev3:
  * Document only exectuables in phase dirs policy
* Tue Jun 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.48.dev2:
  0.1.47
  * Optimize Python install in deploy-targetcli
  * dib-lint: make it work on Mac OS X
* Sat Jun 27 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.47.dev23:
  * Have glean set hostname if a config drive exists
  * Add oat-client element
  * Change simple-init to use a PATH variable
* Fri Jun 26 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.47.dev17:
  * Allow source-repositories ref to be "*"
  * Only chown tmp dirs when they are a tmpfs mount
  * Updated from global requirements
  * Wait longer for root device to become available
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.47.dev10:
  * Revert "Revert "Ensure DIB_RELEASE is exported for fedora""
  * Add debian build test case
* Sun Jun 14 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.47.dev8:
  * Dont fail if were missing setfiles
  * Revert "Remove unused map_nbd function"
  * CentOS-6 resize support
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.47.dev3:
  0.1.46
  * Revert "Ensure DIB_RELEASE is exported for fedora"
  * Follow symlink for elements
  * Add Ironic API version to passthru URL for deploy-ironic
  * Skip backups and other non-relevant files for dib-lint
  * Add smoketest for fedora
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev52:
  * Add grub2 element
  * Address follow-up comments
  * Use tar -t instead of -l because centos 6
* Wed Jun  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev46:
  * Don't log tmpfs message during cleanup
  * Ensure DIB_RELEASE is exported for fedora
* Tue Jun  2 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev42:
  * Support custom kernel cmdline args for deploy iso
* Sat May 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev40:
  * Make it clear that tmpfs is optional
  * rhel-common element should not use attach with activation key
  * Make $DIB_YUM_REPO_CONF accept a list of repo files
  * Cleanup /tmp in the guest
  * Fix disk image create errors behind proxy
* Sat May 23 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev31:
  * Pass glean output to the console log
  * Use environment setfiles
* Fri May 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev28:
  * redhat-common: rename 01-clean-old-kernels.sh to drop .sh extension
  * Install debian locales
  * Simple-init should disable cloud-init
* Thu May 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev22:
  * Initial element tests
* Thu May 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev20:
  * doc: small snippet about operating system elements
  * Use Centos 7 cloud image symlink
  * Have simple-init regenerate ssh keys on boot
* Wed May 20 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev14:
  * Export DIB_RELEASE in centos
  * Update install docs to be more user friendly
* Sat May 16 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev12:
  * vm: use $DISTRO_NAME instead of lsb_release
  * rax-nova-agent: switch to $DISTRO_NAME
  * ramdisk: switch from lsb_release to $DISTRO_NAME
  * centos/centos7: switch to epel element
* Thu May 14 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev5:
  * Add packages required for iscsi extension in agent
* Wed May 13 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev4:
  * Make managing hosts entries optional
  * force arch amd64 for EL7 elements
* Tue May 12 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.46.dev1:
  0.1.45
  * Address comments on virtual media device label commit
* Sun May 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev19:
  * Remove install of vlan/vconfig from base
* Fri May  8 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev18:
  * package-installs: fix error case for Python 2.6
  * epel: support centos element
  * Package ldlinux.c32 along with isolinux.bin if it exists
  * Fix $DIB_DEFAULT_INSTALLTYPE export statement
  * Support arch-specific package-installs
* Thu May  7 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev9:
  * debootstrap: fix syntax issues
  * Turn docs warnings into errors and fix issues
* Wed May  6 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev6:
  * Remove unused map_nbd function
* Wed May  6 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev5:
  * Add install_test_deps script
* Tue May  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev3:
  * Actually set a sane PATH for inside chroot
* Mon May  4 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.45.dev2:
  * Mount with -o nouuid for XFS base images
* Fri May  1 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.44.post2:
  * Download of translations not properly disabled in APT
* Thu Apr 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.44:
  0.1.44
  * debian-minimal: Remove -backport's restricted + universe
  0.1.43
  * Generate locales in debian-based elements
  * Use labels for virtual media dev in Ironic ramdisk
  * Fix to load only signed kernel in UEFI secure boot
* Wed Apr 29 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post60:
  * Split the debootstrap functions into an element
  * Add element ubuntu-signed to provide signed kernel
  * Clean up targetcli ramdisk installation
* Tue Apr 28 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post54:
  * Updated from global requirements
* Mon Apr 27 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post52:
  * Install glean from openstack source
  * Add functional smoke test for disk-image-create
  * Port centos-minimal to yum-minimal
  * Use shorter temporary file names for kpartx
  * Append full path to img-functions:run_in_target
  * Add a yum-minimal element that just uses yum
  * Add element to process config-drive network info
  * Break install-types out of base
  * Support VHD output format
  * Make troubleshoot work with dracut ramdisks
  * Add generic devuser element
  * Update cloud-init-datasources README
  * Generate the default en_US locale
  * Create the dracut directory if not existing already
  * Fix dhclient in Fedora ramdisks
  * Dont try to unmount if were not using tmpfs
  * Allow setting DIB_PIP_RETRIES
* Wed Apr 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post19:
  * Fix image size to fit filesystem journal
  * update the dib centos7 baseurl to use a mirrorlist
  * openSUSE update
  * Switch default Fedora image to F21
  * Don't trace RHEL Registration scripts
  * Try 5 times for rmdir command call after umount
  * Open MKFS_OPTS for extension in disk-image-create
* Sun Apr 19 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post5:
  * Updated from global requirements
* Thu Apr 16 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post4:
  * Update packages earlier
* Wed Apr 15 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.42.post2:
  0.1.42
  * Do not export REG_HALT_UNREGISTER between hook scripts
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.41.post51:
  * No markdown docs for elements
* Thu Apr  9 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.41.post49:
  * Improved apt-sources README
  * Export image properties
  * Correctly handle raw type ordering
* Sun Apr  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.41.post44:
  * Create a user guide
* Fri Apr  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.41.post42:
  * Report status of boot loader installation to Ironic
* Thu Apr  2 2015 mmeister@suse.de
- Update to version diskimage-builder-0.1.41.post40:
  * Use find instead of ls
  * Reorder tox environments
  * Run svc-map tests
  * Short circuit qemu-img convert for raw images
  * Split dib-init-system into its own element
  * Handle non-cloud-init installs
  * Run udevadm settle after kpartx -l
  * Refactor deploy ramdisk to allow use of targetcli
  * Fedora: install redhat-rpm-config
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.41.post22:
  * Add py34 to tox
* Fri Mar 27 2015 rsalevsky@suse.com
- Update to version diskimage-builder-0.1.41.post21:
  * Allow elements to add drivers to dracut
  * Cleanup/restify components.rst
  * redhat-common: Fix MariaDB-Galera-server case
  * Flagging ubuntu-minimal as untested 0.1.41
  * Ironic: Deploy ramdisk to find the right root device
  * Ironic: uefi localboot support
  * Convert leftover unconditional set -x to DIB_DEBUG_TRACE
  * Fix check for installtype
  * Fix incorrect package name dmidecoded to dmidecode
  * ironic-agent: exclude content of /tmp from initramfs
  * UEFI secure boot support for iso element
  * Install Fedora kernel-modules pkg for iscsi_tcp
  * Allow disabling apt-get clean
  * Set DIB_RELEASE in ubuntu element
  * CentOS 6 Element
  * Fix race in svc-map
  * Use package-installs on dpkg-based elements
  * openSUSE update
  * package-installs: work with Python < 2.7
  * Split out README into separate files
  * Add wget to package-installs.yaml for epel
  * Updated readme
  * Fix unbound variables in apt-{preferences,sources}
  * pkg-map: respect --missing-ok also on missing pkg-map file
  * update epel version number in epel element
  * Add a link to the "Writing an element" section
* Tue Feb 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.40.post16:
  * Pass BOOTIF to ironic-discoverd from the ramdisk
  * Enable vm element to create PowerPC image
* Sat Feb  7 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.40.post13:
  * Add apt-get autoremove
  * Add install-static element
  * Use sudo -E when squashing package installs files
  * Ironic: Local boot
  * Set http_proxy to retrieve the signed Release file
  * Add minimal ubuntu and centos base elements
* Thu Feb  5 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.40.post2:
  0.1.40
  * setfiles consistently
  * Add support for using local PowerPC VM image
  * ramdisk-image-create: add support for vmlinux file
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.39.post10:
  * Corrected `element-info` usage
  * Add installtype support to package-installs
  * Use DIB_IMAGE_CACHE in dpkg element
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.39.post4:
  * Fix issue with leaking /tmp/image.* directories
* Wed Jan 28 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.39.post3:
  * ironic-discoverd-ramdisk element cleanup
* Sun Jan 25 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.39.post2:
  0.1.39
  * Run Registration Once
* Thu Jan 22 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post39:
  * Switch manage_etc_hosts from True to localhost
  * Add install section to Ironic agent systemd service file
  * Fallback to a boot_server kernel param if ip= not passed
* Wed Jan 21 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post34:
  * Fix Satellite Repo
  * Disable all interfaces on eni systems
* Tue Jan 13 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post30:
  * Fix for RHEL6
  * Allow for disabling rhel registration
* Sat Jan 10 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post26:
  * Add element for ubuntu-core
  * Add rax-nova-agent element
  * Deprecates username and password from boot time registration
  * Fix repo enablement for RHEL during registration
* Fri Jan  9 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post18:
  * dracut-ramdisk: fix support for elements with ramdisk-install.d
  * Continue past dependency ordering diffs
* Wed Jan  7 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post14:
  * Ignore stderr from pkg-map
  * Add Activation Key Support For Customer Portal
* Sat Jan  3 2015 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post10:
  * Don't trace RHEL registration scripts
* Wed Dec 24 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.post8:
  * Allow absolute path to image with ironic-agent
  * Fail helpfully if uuidgen is missing
* Wed Dec 17 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.4.g9a53631:
  * Fix rst rendering
* Fri Dec 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.38.2.g2dfb931:
  0.1.38
  * Rework package-installs to collapse on build host
  * Use env python
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.37.20.g1273cd5:
  * Add some speedups to dpkg
  * Migrate to new package-installs
  * Improve --ramdisk-element docs
* Wed Dec 10 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.37.14.gb74bb64:
  * Allow injecting arbitrary yum repo configuration
  * Don't use lsb_release
  * Add element for hardware discovery ramdisk for ironic-discoverd
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.37.9.ge5b8656:
  * Add new package-installs system
  * Remove the grub2 install from redhat-common
* Tue Dec  2 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.37.6.g2d7885a:
  * Remove use of sudo from yum pre and post elements
  * disk-image-create: fix test when no argument is given
* Sat Nov 29 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.37.2.gc4ad904:
  * Unset requiretty if it exists in sudoers
  0.1.37
* Fri Nov 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.18.g83c97e8:
  * Allow multiple identical sources
* Thu Nov 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.16.g37ec06c:
  * Warning when using pypi element without a mirror
* Wed Nov 26 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.14.gccf95e7:
  * Make some pkg-map errors soft
  * Fail helpfully if no elements are specified
  * Check python with flake8 instead of dib-lint
  * Update RHEL Registration
* Sun Nov 23 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.6.g019196e:
  * Add deprecation warning when using map-services
* Sat Nov 22 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.4.gd8b156d:
  * Add DIB_DEBOOTSTRAP_EXTRA_ARGS environment variable
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.36.2.gd506c42:
  0.1.36
  * Deprecate map-packages, replaced by pkg-map
  * deploy-kexec depends on deploy
  * Remove duplicate binary-deps from dracut-ramdisk
  * Add element for building ramdisk with ironic-python-agent
  * Simplify Dracut cmdline script
  * Enable RHEL Registration
* Fri Nov 14 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.27.gce67ce8:
  * Support installing packages by default
* Thu Nov 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.25.g6fedbc5:
  * Fix indent exclusion
* Wed Nov 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.24.gcbdf218:
  * Install PyYAML for the svc-map element
* Tue Nov 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.22.gc26a9ee:
  * Install lsb_release from package
* Sat Nov  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.21.gcafad0a:
  * Update Debian repo to retrieve signed Release file
* Fri Oct 31 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.19.gd72435a:
  * Optimize speed of deletion in find command
  * Unset trap before dracut ramdisk build script exits
* Thu Oct 30 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.15.g1e5ec9a:
  * Use binary-deps.d for dracut ramdisks
* Wed Oct 29 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.13.g47502b8:
  * export DIB_ROOT_LABEL to make it global
* Tue Oct 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.11.gdbe2846:
  * package-installs assumes packages have a pkg-map
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.35.9.g3c8cf6a:
  * Updated from global requirements
  * iso element to use 'search --label' for grub
  0.1.35
  * Move busybox binary-dep to ramdisk element
  * svc-map requires PyYAML
  * iso element to build bootable ISO images
  * Handle extra spaces in merge-svc-map-files
  * Enable dracut deploy ramdisks
  * Revert "introduce $SYSTEMD_SYSTEM_UNIT_DIR"
  * Avoid overwritting of hooks
  * Allow source-repositories to be disabled completely
  * Make diskimage-builder work in Docker
* Fri Oct 17 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.34.10.g2b60bea:
  * Remove first-boot.d support
  * Force empty $TMPDIR inside the chroot
  0.1.34
  * Consolidate lsb_release source-repositories
  * Allow for multiple image outputs from raw source
  * Don't re-install cloud-init for centos7 images
* Thu Oct 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.33.7.g97678dc:
  * Move to final release of CentOS7 images
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.33.6.g16b0e5e:
  * Echo that qemu-img convert is running
  * Preserve exit value when leaving cleanup trap
* Fri Oct 10 2014 tbechtold@suse.com
- Update to version diskimage-builder-0.1.33.3.g4b05499:
  * Check for epel before installing it
  0.1.33
  * Do not try to detach non-existant loopback devices
  * Move install bin from rpm-distro to yum
  * Use DIB_IMAGE_CACHE everywhere
  * Save extended attributes when creating tar
  * Ensure epel7 is installed only on rhel7/centos7
  * Update EPEL release rpm
  * Fix $DISTRO_NAME usage for centos7 element
  0.1.32
  * Add unit test for cache-url
  * Install openstack-selinux on RHEL
  * Move dpkg manifest creation to finalise
  * Handle non-existing *generic kernel and initrd
  * Fix openSUSE cloud image download and extraction
- 0001-Fix-openSUSE-cloud-image-download-and-extraction.patch dropped.
  Applied upstream.
- Add python-oslotest as BuildRequires.
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.31.22.gde60893:
  * Use $((EXPRESSION)) instead of $[EXPRESSION]
* Tue Sep 30 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.31.20.g4690471:
  * Updated from global requirements
* Tue Sep 30 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.31.19.gdde3d24:
  * Allow custom rootfs labels
* Sat Sep 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.31.18.g89356c6:
  * Add svc-map element
  * Refactor ramdisk element to allow alternate implementations
* Wed Sep 24 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.31.14.gdbc60e8:
  * Updated from global requirements
  * Provide ability to build images for other architectures
  * Change order for yum-repos file in centos7 element
* Mon Sep 22 2014 dmueller@suse.com
- Update to version diskimage-builder-0.1.31.8.gb308c84:
  * Adds EPEL repo, cleans up rhel7 repos
  * Update to newer Centos7 images
  0.1.31
  * Add ceilometer service mappings
  * Use dib-run-parts from dib-utils
* Tue Sep 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.30.6.g93be491:
  0.1.30
  * Run environment.d hook for manifests earlier
  * Reset yum configuration in post-install.d
  * Add vmedia boot support for deploy-ironic element
* Sat Sep 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.29.27.g60fdfb2:
  * opensuse: Support pkg removal in install-packages
  * Fix ramdisk pkg-map for openSUSE
* Fri Sep 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.29.23.gf401199:
  * Lock around extract-image downloads and extracts
* Wed Sep 10 2014 dmueller@suse.com
- Update to version diskimage-builder-0.1.29.21.g9fb2c14:
  * Use package-installs in more elements
  * Replace backticks with $()
  * Fix openSUSE kernel/initrd detection
  * Correct statement about ramdisk and tmpfs
  * Changed serial console setup
  * Formatting fixes for dhcp-all-interfaces
  * debian: exclude contents of /tmp from debootstrap tarballs
* Fri Sep  5 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.29.7.g9785c27:
  * Add support for flashing ILO BMC's from ramdisks
  * Use package-installs in fedora
  * package-installs for pre-install.d/post-install.d
* Thu Sep  4 2014 dmueller@suse.com
- Update to version diskimage-builder-0.1.29.1.g697e771:
  * Fix for host env leak into grub
  0.1.29
  * Add element-manifest
  * Map dkms package for SUSE in base element
  * Fix capitalization of openSUSE
  * Remove disable_interface from dhcp-all-interfaces
  * Extend/fix support for extlinux bootloader
* Tue Sep  2 2014 dmueller@suse.com
- replace 0001-Use-the-stable-symlink-for-downloading-openSUSE-imag.patch,
  0002-openSUSE-Fix-code-to-unpack-the-qcow2-image.patch with
  0001-Fix-openSUSE-cloud-image-download-and-extraction.patch
* Mon Sep  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.28.14.g72b4179:
  * Cleanup apt cache after grub install
  * Bump hacking to 0.9.x series
* Sun Aug 31 2014 dmueller@suse.com
- add 0001-Fix-openSUSE-kernel-initrd-detection.patch
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.28.10.g7da217b:
  * Truncate instead of deleting log files
  * Remove docs about deprecated pypi-mirror tool
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.28.6.g7d0e7fe:
  * Make RHSM registration set -u safe
  * Centralize handling of /lost+found
* Thu Aug 28 2014 dmueller@suse.com
- add 0001-Use-the-stable-symlink-for-downloading-openSUSE-imag.patch
  0002-openSUSE-Fix-code-to-unpack-the-qcow2-image.patch
  0003-Fix-capitalization-of-openSUSE.patch
  0004-Fix-ramdisk-pkg-map-for-openSUSE.patch
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.28.2.gd5caf44:
  0.1.28
  * Add dib-lint exclusions
* Tue Aug 26 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.27.16.gc393ed3:
  * Revert "Remove the temporary deploy element after rename"
  * map-services: add openstack-nova-novncproxy
  * Create cache directory
* Mon Aug 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.27.10.gc445a6c:
  * Support for UBoot
* Thu Aug 21 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.27.8.g45693f5:
  * Add service mappings for ironic
* Wed Aug 20 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.1.27.6.g354c498:
  * Remove hardcoded version
  * Increase source-repositories support for tarballs
* Tue Aug 19 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev2.g8d16583:
  * Allow to specify an empty package list in pkg_map
  0.1.27
* Thu Aug 14 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev6.g4d4b104:
  * Don't try to install if packages is empty
* Wed Aug 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.g8c72451:
  * Relabel filesystem if SELinux is available
* Tue Aug 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev2.g77fae1a:
  0.1.26
  * Tidy base image by removing /var/log files
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev35.gf303b65:
  * Remove package mapping for mariadb-rdo-galera-server
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev33.g2805131:
  * Avoid to install a blank list of packages
  * Add a ramdisk-install.d hook path
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev29.ge818db2:
  * Adds RHEL common element
* Mon Jul 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev27.g32aa9da:
  * Fix sourcing of environment files
  * Add virtual media boot support in ramdisk element
* Sat Jul 26 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev23.g673f6aa:
  * Revert "Cleanup apt cache after grub install"
  * Update RHEL7 element since release
  * Initial centos7 support
  * Handle non-script grub2-install
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev15.gd44fcda:
  * Lock around source repositories setup
* Wed Jul 23 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev13.g22cf8e8:
  * Cleanup apt cache after grub install
  * Lock around ubuntu tarball download
  * Explicitly name element enable-serial-console
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.gd9d43c6:
  * Update RHEL 6.5 Image name
* Sat Jul 19 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev6.gfc5e791:
  0.1.25
  * Add dhcp support for ramdisk element
  * Use readlink to get script path
  * Echo output when pkg-map fails
* Wed Jul 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.g6f7af6f:
  * Detail 'other' directories in the README
  * Allow overwriting old images
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.gc9bcce2:
  0.1.24
  * Optimizing directory creation
  * Avoid to install a blank list of packages
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev15.g4e97def:
  * Correction: if then statement code style
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev13.ge93d365:
  * Really handle Ubuntu mirror cache skew,
  * Add global exclusions to dib-lint
  * Remove fixfiles from rpm-distro finalize
* Tue Jul  8 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev7.gbbf62fc:
  * Revert "Don't match editor backup files in env..
  * Last ditch effort to correct a wrong shasum
  * Rename rhel element yum blacklist
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev2.g92d4ed7:
  * Don't match editor backup files in environment
  0.1.23
* Fri Jul  4 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev38.g61c192e:
  * Set LC_ALL=C into dib-run-parts env
  * Add RHEL7 to Red Hat family in pkg-map
* Wed Jul  2 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev34.g451e571:
  * update opensuse element
  * VM element: Enable serial console on Debian
  * Element to remove unwanted kernel/initrd
  * Update README regarding Debian and OpenSUSE support
  * Create an element to allow using a dpkg manifest
* Tue Jul  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev24.g5ee5aa5:
  * Remove uneeded code from pkg-map
* Sat Jun 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev22.g5151dc0:
  * Use $DISTRO_NAME instead of local lsb_release
  * Always bind-mount pypi mirror if dir exists
  * Disk-image-create should allow sending compat flags to qemu-img
  * Update base element to make use of pkg-map
  * opensuse: support pkg-map in bin/install-packages
  * dpkg: support pkg-map in bin/install-packages
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev10.gf866a6f:
  * Use common element select-boot-kernel-initrd
  * introduce $SYSTEMD_SYSTEM_UNIT_DIR
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev6.g14741f3:
  * Add select-boot-kernel-initrd element
  0.1.22
  * Ignore manifest outputs more carefully
  * Ensure cache directory exists before use
  * update zypper element
* Wed Jun 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.g20879b2:
  0.1.21
  * Drop ending slash from DIB_CLOUD_IMAGES
  * avoid failure if /lib/firmware doesn't exist
  * map-services: add openvswitch
  * Factor out error behavior in dib-lint
* Fri Jun 20 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev24.g6744030:
  * debian: fix network on Wheezy
* Thu Jun 19 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev22.g45d5bf4:
  * Do not use DatasourceNone for precise cloud-init
  * dpkg: local cache for .deb files
* Tue Jun 17 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev18.g12ae39b:
  * Ensure dib-run-parts profiling works with py3 and py2
* Mon Jun 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev16.g1b71aaf:
  * Add missing dollar
* Sat Jun 14 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev14.gc050129:
  * Refactor code to select boot kernel
  * Add manifests to .gitignore
* Fri Jun 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev10.g786899e:
  0.1.20
  * fail at startup with no operating-system element
  * Add test to ensure we don't duplicate filenames
  * Name deploy-ironic and deploy-baremetal files uniq
  * Name 10-rhel-cloud-image uniquely
  * Name 01-install-bin uniquely
  * Delete redhat-common 00-usr-local-bin-secure-path
  * Yum: support pkg-map in bin/install-packages
  * Rename old image file instead of rewrite it
  * Replacing deploy to deploy-baremetal in README.md
  * Fix package removal
* Thu Jun 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev22.g662782b:
  * Name 99-setup-first-boot uniquely
  * Add tar as an output type
  * Correct source-repository comments
  * Correct the wrong rename in rhel element
* Thu Jun 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev14.g2a1c189:
  * Tidy up SuSE kernel selection
  * Parameterise PXE kernel and initrd selection
  * Debian: Support additional debootstrap arguments
* Wed Jun 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.g6ff1681:
  * Reinstate Trusty as default for Ubuntu
  * Check return code of element-info
* Tue Jun 10 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.g336398d:
  * Only use Ec2 cloud-init data source for Ubuntu
  * Add new cloud-init-datasources element
  0.1.19
* Sat May 31 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev1.g50cb019:
  * Set DISTRO_NAME in OS environment.d
  0.1.18
  * Add pkg-map element
* Thu May 29 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev9.g4382791:
  * dib-lint: ensure file finish with a new line
  * add some missing \n at end of file
* Wed May 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev5.gb759cfe:
  * Check for set -o pipefail
  * Set -o pipefail new scripts
  * Add support for source-repos gerrit refs
  0.1.17
* Fri May 23 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev29.gce85042:
  * Stop using bash arrays for whitelisting in yum
  * Export unbound variable DIB_RHSM_USER
  * Ensure scripts are set -u
  * Remove the temporary deploy element after rename
  * Add switch to turn on caching for debian element
* Thu May 22 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev19.g9941326:
  * `set -u` doesn't permit bash arrays to test -n
* Wed May 21 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev17.g44922b8:
  * Ensure we can read the kernel out
* Tue May 20 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev15.gf70a9fa:
  * Fedora: Add support for configuring Yum mirrors
  * Add map-services for debian distros
* Thu May 15 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev11.g5b16eb0:
  * indent: search for !=4 spaces indentation
  * 4 spaces indent
* Tue May 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev7.gdcb5f57:
  * Move instead of copy the temporary git manifest
* Sat May 10 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev5.g83aee34:
  * Updated from global requirements
  * Adding -x to set parameters for more output
* Fri May  9 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev2.gdcb5494:
  0.1.16
  * set -u and -o pipefail everywhere
  * Build raw image in separate tmpfs
* Thu May  8 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev16.g578c2e4:
  * dib-lint: check for tab indent in files
* Wed May  7 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev14.g35d18b8:
  * Make sure all scripts are set -e
  * Allow excluding tests from certain files
  * Eliminate 'tr' in favor of inline bash
  * Support declarative package installs/uninstalls
* Sat May  3 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.g928e6f2:
  * debian: properly deal with Debian stable/unstable
  * Add sysv support to elements/dhcp-all-interfaces
* Thu May  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.gb46ece4:
  0.1.15
  * Permit cache-url to work with fifos
  * debian: add systemd support
  * debian: support upstart on Wheezy
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev19.g8bba3a2:
  * Debian element should activate eth0
  * set -e all the things
  * Explicitly use bash
  * Add package uninstall support
  * Map openjdk-7-jre-headless to RHEL+SUSE
  * cleaning up 01-copy-manifests-dir
* Mon Apr 28 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.g1877784:
  * Respect inmutable resolv.conf in the image
* Sun Apr 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev6.gb1e8c08:
  * Add a mapping for kernel headers
* Sat Apr 26 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev4.gdb1ba39:
  * Remove All Rights Reserved
  0.1.14
  * Revert default Ubuntu release back to Saucy
  * Place /usr/lib64/ccache in PATH
* Fri Apr 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev27.g0303108:
  * indent: replace tab by 4 spaces
  * Disable splashimage for legacy grub
* Thu Apr 24 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev23.g6b2a78f:
  * Sort rhel/bin/map-packages
  * Small fixes for dhcp-all-interfaces
  * Make "trusty" (Ubuntu 14.04) the default release
* Sat Apr 19 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev19.gb588e4a:
  * Use provides to note an element provides deploy
  * Remove dependency on /etc/lsb-release
  * debian: simplify the way debian element is called
  * Add ability to add extra apt keys
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev11.g7b1c2b9:
  * Remove cloudy interfaces in dhcp-all-interfaces
  0.1.13
  * apt-conf: uninitialised variables fix
  * doc: indentation rules for element
  * Document a little the concerns for operators
  * Change refspec used to fetch all branches and tags
  * Fix Grub configurations for Fedora images built on a UEFI host
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev15.ged5a872:
  * Fix set -eu and pipefail failures
  * Add mapping for mariadb rdo package
  * map-services: add apache2 in the list
  * Remove map-services from fedora element
* Wed Apr 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev7.g66445de:
  * Fix dhcp-all-interfaces on Ubuntu/Debian
* Sun Apr 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev5.gae9ccc4:
  * Remove call to depmod in busybox
* Sat Apr 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev3.gb1a4eda:
  * Standardise manifest creation and retrieval
* Fri Apr 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev1.g793dae8:
  * Use provides to note an element provides an OS
  0.1.12
* Wed Apr  9 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev7.g0fc211a:
  * Iterate over provided elements first
  * debian: use sudo to create file in the chroot
  * fix grub2 installation on Debian Wheezy
  0.1.11
  * Remove hardcoded /tftpboot/ from token's tftp path
* Thu Apr  3 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev13.gf49e8a4:
  * Fix dhcp-all-interfaces upstart job
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev12.gc787539:
  * Fix resource exhaustion with upstart
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev11.g6090f52:
  * Write a dpkg manifest to list installed packages
  * Fix "(None)" seed hostname on Debian
  * dhcp-all-interfaces: correct ifquery return stmt
  0.1.10
  * Make stable-interface-names its own element
  * Uses policy-rc.d to prevent dpkg starting daemons
  * Enforce alphabetical ordering of element-deps
  * Alphabetize all element-deps
  * Add dib-lint script
  * Adds package mapping for mariadb packages
  * Adding pypi-mirror dependencies for redhat
  * Revert "Only create a tmpfs big enough for DIB_MIN_TMPFS"
  * debian: install cloud-init on Wheezy
  * Remove an excess cp of disk images
  * Adds "element-provides" support to element dependencies
  * Add console kernel parameters to extlinux configuration
  * rename udev.rules to dhcp-all-interfaces-udev
  * serial-console: Use udev rules to startup getty
  * Only create a tmpfs big enough for DIB_MIN_TMPFS
* Wed Mar 26 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev8.g440de95:
  * Permit use of wheel mirrors in pypi element
  * baremetal: correct the path of ifcfg-eth0
  * Set +x on executable files
  * DHCP: make udev rules want dhcp-interface@.service
* Tue Mar 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev1.g2f24062:
  * Adds libmariadb-dev package mapping
  0.1.9
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev67.g9480554:
  * Add RHEL 7 image element
  * Use redhat-common in fedora element
  * Add redhat-common element
  * Correct README.md markdown errors
  * Update openSUSE package mapping for libffi-dev
* Tue Mar 18 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev57.g5af4c26:
  * Support adding DHCP interfaces one at a time
  * Move install type enablement into base element
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev53.g3f9299e:
  * RHEL Package maps for build-essential, python-dev and libz-dev
  * Extract move cache logic to a function
  * Always export IMAGE_NAME
  * Add apache2 mod_wsgi pkg map for suse
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev45.gbae43c9:
  * Create a git manifest from source-repositories
  * 98-source-repositories tries to return from script
  * Better apt-sources docs
  * Enable extlinux support for (non-Ubuntu) Debian platforms
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev37.g6f8f6b0:
  * baremetal element: Enable stable interface names
  * Fixup all occurrences of REPONAME for replacing '-'
  * Add libaio1 to libaio pkg map for fedora
  * Fix unbound variable in debian element
* Wed Mar 12 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev31.gffdd57b:
  * Updated from global requirements
  * Additional swift storage service mappings
  * Replace more then just "-" in REPONAME
* Tue Mar 11 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev26.g1080b40:
  * Add nfs-common package mapping
  * Bash eval the lines in source-repository scripts
  * Add rsync to the package list used by debootstrap
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev21.gcfdad8e:
  * Alphabetize openSUSE services dictionary
  * Alphabetize openSUSE packages dictionary
  * Alphabetize Fedora services dictionary
  * Alphabetize Fedora packages dictionary
  * Update README formatting and content
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev11.ge602863:
  * Replace use of show-ref with name-rev
  * Fix syntax error in GRUB_OPTS env var handling
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev7.g9595197:
  * Fix spelling error in "vm" element README.md
  * Add $EXTRA_ARGS back to yum call
  * Update the image name for RHEL Guest Image
  0.1.8
  * Improve usability of the source-repositories cache
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev11.ge5afa4d:
  * Improve local-config proxy handling
  * Enable custom apt.conf in apt-conf element
  * Enable simple modification of git repo location
  * Add NFS package mapping
  * Generalize install-packages for yum
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev2.g61d474f:
  0.1.7
  * Update pypi element to suggest pypi-mirror
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev25.ga84611d:
  * Replace security.ubuntu.com when setting mirror
* Sat Feb 22 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev24.g6360b46:
  * Add 00-fedora-fixup-vim
  * Permit using arbitrary PyPI urls
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev20.g959aed3:
  * Remove accidental merge marker
  * Add libvirt-bin -> libvirtd to map-services
  * Make max-online-resize an option
  * Correct DIB long option parsing
  * Pep8/Pyflakes fixing
  * Shift debian element to DIB_DISTRIBUTION_MIRROR
* Sun Feb 16 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev12.g621376d:
  * Teach cache-url to handle file:// URIs
  * Remove tox locale overrides
  * Rename Openstack to OpenStack
* Fri Feb 14 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev6.g1dfd4b3:
  * Revert "Add Fedora DHCP interfaces via udev rules."
  * Revert "Support adding DHCP interfaces one at a time. "
  0.1.6
  * Add Fedora DHCP interfaces via udev rules
  * Support adding DHCP interfaces one at a time
  * Don't hardcode environment.d
* Thu Feb 13 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Fix-kernel-extraction-on-openSUSE.patch dropped (merged upstream)
* Thu Feb 13 2014 cloud-devel@suse.de
- Update to version diskimage-builder-0.0.1.dev43.ga3f2836:
  * ifquery doesn't exist on Fedora
  * Fix kernel extraction on openSUSE
* Tue Feb 11 2014 speilicke@suse.com
- Update to version diskimage-builder-0.0.1.dev39.g983f918:
  * Add more package name mappings for openSUSE
  * Add lsof package to all Fedora images
  * Remove unneeded service mapping for mysql on openSUSE
  * Fix misspellings in diskimage-builder
  * Adjust neutron package install for Fedora
  * Make the MIRROR_TARGET directory if it didn't exist
- Rebased patches:
  + 0001-Add-more-package-name-mappings-for-openSUSE.patch dropped (merged upstream)
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
- Drop useless requirement on python-d2to1
* Fri Feb  7 2014 dmueller@suse.com
- add 0001-Add-mapping-for-openvswitch-daemon-openSUSE.patch
* Tue Feb  4 2014 dmueller@suse.com
- add 0001-Update-openSUSE-package-mappings-for-OpenStack.patch
* Tue Feb  4 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev22:
  + Add Fedora packages mappings for snmpd
  + Update map-services for Fedora
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev19:
  + Skip relabel unless SELinux is enforcing
  + Add package map for stunnel4
  + Add ability to use local cloud image
* Tue Jan 28 2014 bwiedemann@suse.com
- Dropped patches merged upstream:
  + 0002-Add-a-service-mapping-for-openSUSE.patch
  + 0001-Fix-tftp-mapping-on-openSUSE.patch
  + 0001-Use-usr-bin-env-not-bin-env.patch
  + 0001-Workaround-broken-udev-update-on-openSUSE.patch
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev13:
  + Add a service mapping for openSUSE
  + Use /usr/bin/env, not /bin/env
  + Include /lib64 into the deploy ramdisk on openSUSE
  + Add bash as a dependency to the deploy ramdisk
  + Fix tftp mapping on openSUSE
* Mon Jan 27 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Fix-ramdisk-element-for-openSUSE.patch dropped (merged upstream)
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev4:
  + Fix ramdisk element for openSUSE
  + Mount root filesystem readonly during boot
* Fri Jan 24 2014 dmueller@suse.com
- add 0001-Fix-tftp-mapping-on-openSUSE.patch
* Fri Jan 24 2014 dmueller@suse.com
- add 0001-Use-usr-bin-env-not-bin-env.patch
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev50:
  + Move Babel and argparse from test-requirements.txt
  + Add Copyright and License header to debian element
  + Update default RHEL guest image
  + Add support Red Hat Network (RHN)
  + Support list of Red Hat channels and repos
  + Add support for Red Hat Satellite
  + Setup ccache symlinks on openSUSE
  + Workaround broken udev update on openSUSE
  + Fix kernel/initrd extraction for SUSE based distros
  + Add map-services
  + Only configure DHCP for real interfaces
  + Make copy_required_libs() more robust
  + Rename generate-interfaces-file.sh...
* Thu Jan 23 2014 dmueller@suse.com
- add 0001-Fix-kernel-initrd-extraction-for-SUSE-based-distros.patch,
  0001-Fix-ramdisk-element-for-openSUSE.patch,
  0001-Make-copy_required_libs-more-robust.patch
* Wed Jan 22 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev26:
  + Create a new baremetal element
* Tue Jan 21 2014 dmueller@suse.com
- add 0001-Add-map-services.patch
  0002-Add-a-service-mapping-for-openSUSE.patch
* Tue Jan 21 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-usr-bin-move-use-usr-bin-env.patch dropped (merged upstream)
* Tue Jan 21 2014 opensuse-cloud@opensuse.org
- Update to version 0.0.1.dev25:
  + Allow use of mirrors when building Ubuntu images
  + fedora/RHEL: use env from /usr/bin
  + Fix the curl command in the ironic-deploy element
  + Convert -dev to -devel in fedora/map-packages
  + Allow adding packages to debootstrap
  + Fix mysql package mappings for opensuse
  + Add debian-upstart for experimenting with upstart
  + Update to Fedora 20
* Mon Jan 20 2014 dmueller@suse.com
- add 0001-Workaround-broken-udev-update-on-openSUSE.patch
* Mon Jan 20 2014 dmueller@suse.com
- Initial package
